icenet.data.processors package
==============================

Submodules
----------

icenet.data.processors.cmip module
----------------------------------

.. automodule:: icenet.data.processors.cmip
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.processors.era5 module
----------------------------------

.. automodule:: icenet.data.processors.era5
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.processors.hres module
----------------------------------

.. automodule:: icenet.data.processors.hres
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.processors.meta module
----------------------------------

.. automodule:: icenet.data.processors.meta
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.processors.osi module
---------------------------------

.. automodule:: icenet.data.processors.osi
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.processors.utils module
-----------------------------------

.. automodule:: icenet.data.processors.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: icenet.data.processors
    :members:
    :undoc-members:
    :show-inheritance:
